@@ -74,7 +74,7 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
 
 
     def calculateReflectivity(self):
-        imgPath = 'CapturedImages/sequenceImages/8.png'
+        imgPath = 'test.png'
         arr = self.calUpValue(imgPath)
 
         # img = cv2.imread(imgPath, cv2.IMREAD_GRAYSCALE)
