@@ -1,6 +1,6 @@
 from abc import ABC
 from GhostScan.CaptureSession import CaptureSession
-from Projections import Pattern
+from GhostScan.Projections import Pattern
 
 
 class GradientIlluminationCapture(CaptureSession, ABC):
